@@ -8,7 +8,8 @@ def DirectoryResource_get(*args, **kwargs):
     # also contain a directory that contains the final resource
     # i.e. ++resource++foo/css/bar.css
     resource = _original_DirectoryResource_get(*args, **kwargs)
-    if getattr(resource, '__roles__', None) is None:
+    if getattr(resource, '__roles__', None) is None \
+           and hasattr(aq_parent(resource), '__roles__'):
         resource.__roles__ = aq_parent(resource).__roles__
     return resource
 
